@@ -1,10 +1,12 @@
 import argparse
 import json
+import os
 import shutil
 from os import scandir, remove
 from os.path import join
 
 import yaml
+from metasdk.internal import OS_NAME
 
 from metaendpoints.tools import exec_cmd
 
@@ -141,8 +143,13 @@ def get_gen_doc_content(doc_json, service):
 
 
 def build_swagger(service, version_dir):
+    docker_user = ""
+    if OS_NAME == "linux":
+        # Чтобы файлы не создавались под рутом и были доступны на чтение/редактирование из-под локального пользователя
+        docker_user = "--user " + str(os.getuid()) + ":" + str(os.getgid())
     exec_cmd("""
         docker run --rm \
+            {docker_user} \
             -v {version_dir}:{version_dir} \
             -w {version_dir} \
             znly/protoc:0.3.0 \
@@ -151,6 +158,7 @@ def build_swagger(service, version_dir):
             --doc_opt=json,doc_json.json \
             {service}.proto
         """.format(
+        docker_user=docker_user,
         version_dir=version_dir,
         service=service,
     ))
